@@ -1,13 +1,13 @@
 package Venus;
 
-use 5.014;
+use 5.018;
 
 use strict;
 use warnings;
 
 # VERSION
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 # AUTHORITY
 
@@ -103,7 +103,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
 
@@ -147,7 +147,7 @@ handling, "true" and "false" keywords, package introspection, command-line
 options parsing, and more. This package will always automatically exports
 C<true> and C<false> keyword functions (unless existing routines of the same
 name already exist in the calling package), otherwise exports keyword functions
-as requested at import.
+as requested at import. This library requires Perl C<5.18+>.
 
 =cut
 
@@ -697,7 +697,9 @@ B<example 1>
 
   my $myapp = MyApp->new;
 
-  $myapp->catch('execute'); # catch MyApp::Error
+  my $error = $myapp->catch('execute');
+
+  # $error->isa('MyApp::Error');
 
 =back
 
@@ -723,7 +725,9 @@ B<example 1>
 
   $myapp->stash(greeting => 'hello world');
 
-  $myapp->dump('stash'); # '{"greeting" => "hello world"}'
+  $myapp->dump('stash');
+
+  # '{"greeting" => "hello world"}'
 
 =back
 
@@ -761,6 +765,30 @@ B<example 1>
 
 =back
 
+=over 4
+
+=item template-system
+
+This library provides a minimalistic templating system.
+
+B<example 1>
+
+  package main;
+
+  use Venus::Template;
+
+  my $template = Venus::Template->new(q(
+    {{ if user.name }}
+    Welcome, {{ user.name }}!
+    {{ else user.name }}
+    Welcome, friend!
+    {{ end user.name }}
+  ));
+
+  $template->render;
+
+=back
+
 =head1 AUTHORS
 
 Cpanery, C<cpanery@cpan.org>
