@@ -1,6 +1,6 @@
 package Venus::Path;
 
-use 5.014;
+use 5.018;
 
 use strict;
 use warnings;
@@ -138,7 +138,7 @@ sub glob {
   $expr ||= '*';
 
   my @paths = map $self->class->new($_),
-    CORE::glob(File::Spec->catfile($self->absolute, $expr));
+    CORE::glob +File::Spec->catfile($self->absolute, $expr);
 
   return wantarray ? (@paths) : \@paths;
 }
